@@ -5,7 +5,7 @@
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
+#   the Free Software Foundation, either version 2 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -60,13 +60,7 @@ float agc_process(struct agc *s, float input, int mic_is_mute)
    
    float duck_amp;
 
-   if (s->active == 0)
-      {
-      s->red = s->yellow = s->green = s->df = 1.0f;
-      return 0.0f;
-      }
-   
-   /* digital modell of an analog active RC-Highpassfilter network
+   /* digital model of an analog active RC-Highpassfilter network
     * removes DC and subsonic sounds... one stage has 12dB/octave
     * so we badly need to cascade it to make it steep enough ...
     */
@@ -76,23 +70,32 @@ float agc_process(struct agc *s, float input, int mic_is_mute)
    s->RC_HPF1.last_in = input;
    input = s->RC_HPF1.hp;
    
-   input += s->RC_HPF2.q * s->RC_HPF2.bp;
-   s->RC_HPF2.hp = s->RC_HPF2.c * ( s->RC_HPF2.hp + input - s->RC_HPF2.last_in );
-   s->RC_HPF2.bp = s->RC_HPF2.bp * s->RC_HPF2.a + s->RC_HPF2.hp * s->RC_HPF2.b;
-   s->RC_HPF2.last_in = input;
-   input = s->RC_HPF2.hp;
+   if (s->hpstages > 1)
+      {
+      input += s->RC_HPF2.q * s->RC_HPF2.bp;
+      s->RC_HPF2.hp = s->RC_HPF2.c * ( s->RC_HPF2.hp + input - s->RC_HPF2.last_in );
+      s->RC_HPF2.bp = s->RC_HPF2.bp * s->RC_HPF2.a + s->RC_HPF2.hp * s->RC_HPF2.b;
+      s->RC_HPF2.last_in = input;
+      input = s->RC_HPF2.hp;
+      }
    
-   input += s->RC_HPF3.q * s->RC_HPF3.bp;
-   s->RC_HPF3.hp = s->RC_HPF3.c * ( s->RC_HPF3.hp + input - s->RC_HPF3.last_in );
-   s->RC_HPF3.bp = s->RC_HPF3.bp * s->RC_HPF3.a + s->RC_HPF3.hp * s->RC_HPF3.b;
-   s->RC_HPF3.last_in = input;
-   input = s->RC_HPF3.hp;
-   
-   input += s->RC_HPF4.q * s->RC_HPF4.bp;
-   s->RC_HPF4.hp = s->RC_HPF4.c * ( s->RC_HPF4.hp + input - s->RC_HPF4.last_in );
-   s->RC_HPF4.bp = s->RC_HPF4.bp * s->RC_HPF4.a + s->RC_HPF4.hp * s->RC_HPF4.b;
-   s->RC_HPF4.last_in = input;
-   input = s->RC_HPF4.hp;
+   if (s->hpstages > 2)
+      {
+      input += s->RC_HPF3.q * s->RC_HPF3.bp;
+      s->RC_HPF3.hp = s->RC_HPF3.c * ( s->RC_HPF3.hp + input - s->RC_HPF3.last_in );
+      s->RC_HPF3.bp = s->RC_HPF3.bp * s->RC_HPF3.a + s->RC_HPF3.hp * s->RC_HPF3.b;
+      s->RC_HPF3.last_in = input;
+      input = s->RC_HPF3.hp;
+      }
+         
+   if (s->hpstages > 3)
+      {
+      input += s->RC_HPF4.q * s->RC_HPF4.bp;
+      s->RC_HPF4.hp = s->RC_HPF4.c * ( s->RC_HPF4.hp + input - s->RC_HPF4.last_in );
+      s->RC_HPF4.bp = s->RC_HPF4.bp * s->RC_HPF4.a + s->RC_HPF4.hp * s->RC_HPF4.b;
+      s->RC_HPF4.last_in = input;
+      input = s->RC_HPF4.hp;
+      }
 
    /* same RC-Network (but with only one stage and without resonance/feedback (->6dB/octave))
     * used as HF-Detail-Filter 
@@ -316,10 +319,10 @@ float agc_process(struct agc *s, float input, int mic_is_mute)
    return s->buffer[s->out_pos % s->buffer_len]* s->gain;
    }
 
-static void setup_ratio(struct agc *s, float ratio)
+static void setup_ratio(struct agc *s, float ratio_db)
    {
-   s->ratio = ratio;
-   s->roverb = ratio / s->buffer_len;
+   s->ratio = powf(10.0f, ratio_db / 20.0f);
+   s->roverb = s->ratio / s->buffer_len;
    }
 
 static void setup_subsonic(struct agc *s, float fCutoff)
@@ -419,6 +422,7 @@ struct agc *agc_init(int sRate, float lookahead)
    
    /* setup coefficients for the subsonic-and-DC-killer-RC-highpass */
    setup_subsonic(s, 100.0f);
+   s->hpstages = 4;
    
    /* setup coefficients for the HF-Detail highpass */
    setup_hfdetail(s, 4.0f, 2000.0f);
@@ -468,26 +472,15 @@ void agc_free(struct agc *s)
    free(s);
    }
 
-void agc_valueparse(struct agc *s, char *param)
+void agc_valueparse(struct agc *s, char *key, char *value)
    {
-   char *save = NULL, *key, *value;
-
-   key = strtok_r(param, "=", &save);
-   value = strtok_r(NULL, "=", &save);
-
-   if (!strcmp(key, "active"))
-      {
-      s->active = (value[0] == '1');
-      return;
-      }
-
    if (!strcmp(key, "phaserotate"))
       {
       s->use_phaserotator = (value[0] == '1');
       return;
       }
 
-   if (!strcmp(key, "ratio"))
+   if (!strcmp(key, "gain"))
       {
       setup_ratio(s, strtof(value, NULL));
       return;
@@ -548,6 +541,11 @@ void agc_valueparse(struct agc *s, char *param)
       return;
       }
 
+   if (!strcmp(key, "hpstages"))
+      {
+      s->hpstages = (int)(strtof(value, NULL) + 0.5f);
+      }
+
    if (!strcmp(key, "hfmulti"))
       {
       setup_hfdetail(s, strtof(value, NULL), s->RC_HPF5.f);
