@@ -4,7 +4,7 @@
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
+#   the Free Software Foundation, either version 2 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -32,6 +32,7 @@ static int jack_process_callback(jack_nframes_t n_frames, void *arg)
    struct audio_feed *self = arg;
    struct threads_info *ti = self->threads_info;
    struct encoder *e;
+   struct recorder *r;
    sample_t *input_port_buffer[2];
    int i;
    
@@ -65,6 +66,34 @@ static int jack_process_callback(jack_nframes_t n_frames, void *arg)
             fprintf(stderr, "jack_process_callback: unhandled jack_dataflow_control parameter\n");
          }
       }
+      
+   for (i = 0; i < ti->n_recorders; i++)
+      {
+      r = ti->recorder[i];
+      switch (r->jack_dataflow_control)
+         {
+         case JD_OFF:
+            break;
+         case JD_ON:
+            if (jack_ringbuffer_write_space(r->input_rb[1]) >= n_frames * sizeof (sample_t))
+               {
+               jack_ringbuffer_write(r->input_rb[0], (char *)input_port_buffer[0], n_frames * sizeof (sample_t));
+               jack_ringbuffer_write(r->input_rb[1], (char *)input_port_buffer[1], n_frames * sizeof (sample_t));
+               }
+            else
+               /* normally this happens when the CPU is overloaded */
+               r->performance_warning_indicator = PW_AUDIO_DATA_DROPPED;
+            break;
+         case JD_FLUSH:
+            jack_ringbuffer_reset(r->input_rb[0]);
+            jack_ringbuffer_reset(r->input_rb[1]);
+            r->jack_dataflow_control = JD_OFF;
+            break;
+         default:
+            fprintf(stderr, "jack_process_callback: unhandled jack_dataflow_control parameter\n");
+         }   
+      }
+     
    return 0;
    }
 
@@ -120,8 +149,8 @@ struct audio_feed *audio_feed_init(struct threads_info *ti)
    jack_set_process_callback(self->jack_h, jack_process_callback, self);
    jack_on_shutdown(self->jack_h, jack_shutdown_callback, NULL);
    
-   self->input_port[0] = jack_port_register(self->jack_h, "lt_in", JACK_DEFAULT_AUDIO_TYPE, JackPortIsInput, 0);
-   self->input_port[1] = jack_port_register(self->jack_h, "rt_in", JACK_DEFAULT_AUDIO_TYPE, JackPortIsInput, 0);
+   self->input_port[0] = jack_port_register(self->jack_h, "str_in_l", JACK_DEFAULT_AUDIO_TYPE, JackPortIsInput, 0);
+   self->input_port[1] = jack_port_register(self->jack_h, "str_in_r", JACK_DEFAULT_AUDIO_TYPE, JackPortIsInput, 0);
    
    self->sample_rate = jack_get_sample_rate(self->jack_h);
    if(jack_activate (self->jack_h))
@@ -129,8 +158,8 @@ struct audio_feed *audio_feed_init(struct threads_info *ti)
       fprintf(stderr, "audio_feed_init: could not activate jack client\n");
       return NULL;
       }
-   jack_connect(self->jack_h, "idjc-mx:str_lt", "idjc-sc:lt_in");
-   jack_connect(self->jack_h, "idjc-mx:str_rt", "idjc-sc:rt_in");
+   jack_connect(self->jack_h, "idjc-mx:str_out_l", "idjc-sc:str_in_l");
+   jack_connect(self->jack_h, "idjc-mx:str_out_r", "idjc-sc:str_in_r");
    return self;
    }
 
