@@ -4,7 +4,7 @@
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
+#   the Free Software Foundation, either version 2 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -22,8 +22,13 @@
 #ifdef HAVE_AVCODEC
 #ifdef HAVE_AVFORMAT
 
+#ifdef FFMPEG_AVCODEC
+#include <ffmpeg/avcodec.h>
+#include <ffmpeg/avformat.h>
+#else
 #include <libavcodec/avcodec.h>
 #include <libavformat/avformat.h>
+#endif
 
 #include "xlplayer.h"
 
