@@ -4,7 +4,7 @@
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
+#   the Free Software Foundation, either version 2 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -283,11 +283,11 @@ static void id3_tag_read(struct mp3taginfo *ti, FILE *fp)
    int minor, flags;
    struct id3data id;
    
-   if (fgetc(fp) == 'I' && fgetc(fp) == 'D' && fgetc(fp) == '3') 	/* check for ID3 signature */
+   if (fgetc(fp) == 'I' && fgetc(fp) == 'D' && fgetc(fp) == '3')        /* check for ID3 signature */
       {
       ti->version = fgetc(fp); minor = fgetc(fp); ti->flags = flags = fgetc(fp);
-      tagsize = fgetc(fp) & 0x7F;	/* 28 bits of tag size info packed into 4 bytes - big endian */
-      tagsize <<= 7;			/* most significant bit discarded - should be zero */
+      tagsize = fgetc(fp) & 0x7F;       /* 28 bits of tag size info packed into 4 bytes - big endian */
+      tagsize <<= 7;                    /* most significant bit discarded - should be zero */
       tagsize |= fgetc(fp) & 0x7F;
       tagsize <<= 7;
       tagsize |= fgetc(fp) & 0x7F;
@@ -299,7 +299,7 @@ static void id3_tag_read(struct mp3taginfo *ti, FILE *fp)
          case 4:
             if (flags & 0x40)
                {
-               ehsize = fgetc(fp) & 0x7F;	/* skip over the extended header */
+               ehsize = fgetc(fp) & 0x7F;       /* skip over the extended header */
                ehsize <<= 7;
                ehsize |= fgetc(fp) & 0x7F;
                ehsize <<= 7;
@@ -317,9 +317,9 @@ static void id3_tag_read(struct mp3taginfo *ti, FILE *fp)
                }
          case 3:
             frames_end = start + 10 + tagsize;
-	    break;
-	 default:
-            fseek(fp, tagsize, SEEK_CUR);	/* skip over the tag */
+            break;
+         default:
+            fseek(fp, tagsize, SEEK_CUR);       /* skip over the tag */
             return;
          }
 
@@ -334,7 +334,7 @@ static void id3_tag_read(struct mp3taginfo *ti, FILE *fp)
          {
          if (flags & 0x80)
             resynchronise(&id);
-         if (flags & 0x40)		/* lose the extended header */
+         if (flags & 0x40)              /* lose the extended header */
             {
             ehsize = bigendianint(id.data);
             if (ehsize <= id.size)
@@ -350,11 +350,11 @@ static void id3_tag_read(struct mp3taginfo *ti, FILE *fp)
 
       decode_id3_frames(ti, &id);
       free(id.data);
-      if (flags & 0x10)			/* skip over the footer if present */
+      if (flags & 0x10)                 /* skip over the footer if present */
          fseek(fp, 10, SEEK_CUR);
       }
    else
-      fseek(fp, start, SEEK_SET);	/* not ID3 so restore the file pointer */
+      fseek(fp, start, SEEK_SET);       /* not ID3 so restore the file pointer */
    }
 
 /********************************************************************************/
@@ -424,93 +424,93 @@ static void xing_tag_read(struct mp3taginfo *ti, FILE *fp)
          if (bit_rate == 0 || sample_rate == 0)
             frame_length = 0;
          else
-            frame_length = 144000 * bit_rate / sample_rate + padding;
+            frame_length = samples_per_frame / 8 * bit_rate * 1000 / sample_rate + padding;
  
-	 while (xing_offset--)	/* check side info is 100% blank */
-	    if (fgetc(fp) || feof(fp) || ferror(fp))
-	       goto no_tag;
+         while (xing_offset--)  /* check side info is 100% blank */
+            if (fgetc(fp) || feof(fp) || ferror(fp))
+               goto no_tag;
  
-	 if (!fread(xing_intro, 4, 1, fp))
-	    goto no_tag;
+         if (!fread(xing_intro, 4, 1, fp))
+            goto no_tag;
  
-	 if (!memcmp(xing_intro, "Info", 4))
-	    mode = XING_MODE_CBR;
-	 else
-	    if (!memcmp(xing_intro, "Xing", 4))
-	       mode = XING_MODE_VBR;
-	    else
-	       goto no_tag;
+         if (!memcmp(xing_intro, "Info", 4))
+            mode = XING_MODE_CBR;
+         else
+            if (!memcmp(xing_intro, "Xing", 4))
+               mode = XING_MODE_VBR;
+            else
+               goto no_tag;
  
-	 fgetc(fp); fgetc(fp); fgetc(fp);
-	 flags = fgetc(fp);
+         fgetc(fp); fgetc(fp); fgetc(fp);
+         flags = fgetc(fp);
 
-	 if (flags & 0x1)
-	    {
-	    ti->have_frames = 1;
-	    ti->frames = be32bitread(fp);
-	    if (!(ti->tlen) && sample_rate)
-	       ti->tlen = ti->frames / sample_rate;
-	    fprintf(stderr, "frames %d\n", ti->frames);
-	    }
+         if (flags & 0x1)
+            {
+            ti->have_frames = 1;
+            ti->frames = be32bitread(fp);
+            if (!(ti->tlen) && sample_rate)
+               ti->tlen = ti->frames / sample_rate;
+            fprintf(stderr, "frames %d\n", ti->frames);
+            }
  
-	 if (flags & 0x2)
-	    {
-	    ti->have_bytes = 1;
-	    ti->bytes = be32bitread(fp);
-	    fprintf(stderr, "bytes %d\n", ti->bytes);
-	    }
+         if (flags & 0x2)
+            {
+            ti->have_bytes = 1;
+            ti->bytes = be32bitread(fp);
+            fprintf(stderr, "bytes %d\n", ti->bytes);
+            }
  
-	 if (flags & 0x4)
-	    {
-	    ti->have_toc = fread(ti->toc, 100, 1, fp);
-	    fprintf(stderr, "toc has been read\n");
-	    }
-	    
-	 if (flags & 0x8)
-	    be32bitread(fp);
+         if (flags & 0x4)
+            {
+            ti->have_toc = fread(ti->toc, 100, 1, fp);
+            fprintf(stderr, "toc has been read\n");
+            }
+            
+         if (flags & 0x8)
+            be32bitread(fp);
 
-	 if (!fread(lame_intro, 4, 1, fp))
-	    goto no_tag;
-	    
-	 if (!memcmp(lame_intro, "LAME", 4))
-	    {
-	    fprintf(stderr, "lame tag found\n");
-	    fseek(fp, 17, SEEK_CUR);
-	    b1 = fgetc(fp);
-	    b2 = fgetc(fp);
-	    b3 = fgetc(fp);
-	    ti->start_frames_drop = ((b1 << 4) | (b2 >> 4)) + 528;
-	    ti->end_frames_drop = (((b2 & 0xF) << 8) | b3);
-	    fprintf(stderr, "frames to drop %d and %d\n", ti->start_frames_drop, ti->end_frames_drop);
-	    fseek(fp, 12, SEEK_CUR);
-	    }
-	 else
-	    fseek(fp, -4, SEEK_CUR);
+         if (!fread(lame_intro, 4, 1, fp))
+            goto no_tag;
+            
+         if (!memcmp(lame_intro, "LAME", 4))
+            {
+            fprintf(stderr, "lame tag found\n");
+            fseek(fp, 17, SEEK_CUR);
+            b1 = fgetc(fp);
+            b2 = fgetc(fp);
+            b3 = fgetc(fp);
+            ti->start_frames_drop = ((b1 << 4) | (b2 >> 4)) + 528;
+            ti->end_frames_drop = (((b2 & 0xF) << 8) | b3);
+            fprintf(stderr, "frames to drop %d and %d\n", ti->start_frames_drop, ti->end_frames_drop);
+            fseek(fp, 12, SEEK_CUR);
+            }
+         else
+            fseek(fp, -4, SEEK_CUR);
 
-	 if (!frame_length)
+         if (!frame_length)
             save_point = ftell(fp);
   
-	 if (!(ti->have_bytes))
-	    {
-	    fprintf(stderr, "deriving number of bytes manually\n");
-	    fseek(fp, 0, SEEK_END);
-	    ti->bytes = ftell(fp) - initial_offset + frame_length;
-	    ti->have_bytes = 1;
-	    }
+         if (!(ti->have_bytes))
+            {
+            fprintf(stderr, "deriving number of bytes manually\n");
+            fseek(fp, 0, SEEK_END);
+            ti->bytes = ftell(fp) - initial_offset + frame_length;
+            ti->have_bytes = 1;
+            }
 
-	 if (frame_length)
-	    fseek(fp, initial_offset + frame_length, SEEK_SET);
-	 else
-	    {
-	    fprintf(stderr, "manually skipping to the next frame\n");
-	    fseek(fp, initial_offset + save_point, SEEK_SET);
-	    while (fgetc(fp) == '\0');
-	    fseek(fp, -1, SEEK_CUR);
-	    }
-	 
-	 ti->first_byte = ftell(fp);
-	 
-	 return;
+         if (frame_length)
+            fseek(fp, initial_offset + frame_length, SEEK_SET);
+         else
+            {
+            fprintf(stderr, "manually skipping to the next frame\n");
+            fseek(fp, initial_offset + save_point, SEEK_SET);
+            while (fgetc(fp) == '\0');
+            fseek(fp, -1, SEEK_CUR);
+            }
+         
+         ti->first_byte = ftell(fp);
+         
+         return;
          }
       }
 
