@@ -4,7 +4,7 @@
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
+#   the Free Software Foundation, either version 2 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -27,6 +27,11 @@
 
 #define TIMESTAMP_SIZ 23
 
+typedef jack_default_audio_sample_t sample_t;
+
+static const size_t rb_n_samples = 10000;       /* maximum number of samples to hold in the ring buffer */
+static const size_t audio_buffer_elements = 256;
+
 #if 0
 static void recorder_write_ogg_metaheader(struct recorder *self)
    {
@@ -146,27 +151,17 @@ static int recorder_write_id3_tag(struct recorder *self, FILE *fp)
 static int recorder_create_mp3_cuesheet(struct recorder *self)
    {
    struct metadata_item *mi;
-   char *cuepathname, *bp;
+   char *bp;
    FILE *fp;
    int i;
    
-   i = strrchr(self->pathname, '.') - self->pathname + 1;
-   if (!(cuepathname = malloc(i + 4)))
-      {
-      fprintf(stderr, "recorder_write_mp3_cue_sheet: malloc failure\n");
-      return FAILED;
-      }
-   else
-      strcpy(strncpy(cuepathname, self->pathname, i) + i, "cue");
-   
-   if (!(fp = fopen(cuepathname, "wb")))
+   if (!(fp = fopen(self->cuepathname, "wb")))
       {
       fprintf(stderr, "recorder_write_mp3_cue_sheet: failed to open cue sheet file for writing\n");
-      free(cuepathname);
       return FAILED;
       }
 
-   fprintf(fp, "TITLE \"%s\"\r\n", self->title);
+   fprintf(fp, "TITLE \"%s\"\r\n", self->timestamp);
    fprintf(fp, "PERFORMER \"Recorded with IDJC\"\r\n");
    fprintf(fp, "FILE \"%s\" MP3\r\n", strrchr(self->pathname, '/') + 1);
    
@@ -189,7 +184,6 @@ static int recorder_create_mp3_cuesheet(struct recorder *self)
       }
    
    fclose(fp);
-   free(cuepathname);
    return SUCCEEDED;
    }
       
@@ -211,13 +205,14 @@ static int recorder_write_vbr_tag(struct recorder *self, FILE *fp)
    fprintf(stderr, "recorder_write_vbr_tag: commencing\n");
    initial_offset = ftell(fp);
    padding = (self->first_mp3_header[2] & 0x2) ? 1 : 0;
-   framelength = 144000 * self->mi2_first->bit_rate / self->mi2_first->sample_rate + padding;
    mpeg1_f = ((self->first_mp3_header[1] & 0x18) == 0x18) ? 1 : 0;
    mono_f = ((self->first_mp3_header[3] & 0xC0) == 0xC0) ? 1 : 0;
    samples_per_frame = mpeg1_f ? 1152 : 576;
+   framelength = samples_per_frame / 8 * self->mi2_first->bit_rate * 1000 / self->mi2_first->sample_rate + padding;
    xing_offset = side_info_table[mpeg1_f][mono_f];
    if (!fwrite(self->first_mp3_header, 4, 1, fp))
       return FAILED;
+
    for (i = 0; i < xing_offset; i++)
       {
       fputc(0x00, fp);
@@ -254,7 +249,7 @@ static int recorder_write_vbr_tag(struct recorder *self, FILE *fp)
          while (look_ms > mi2->finish_offset_ms)
             {
             mi2 = mi2->next;
-            if (mi2 == NULL)	/* this should never ever happen */
+            if (mi2 == NULL)    /* this should never ever happen */
                {
                fprintf(stderr, "recorder_write_vbr_tag: WARNING: bad metadata, failed creation of seek table\n");
                return FAILED;
@@ -269,8 +264,8 @@ static int recorder_write_vbr_tag(struct recorder *self, FILE *fp)
          fputc('\0', fp);
       }
    frame_fill = framelength - ftell(fp) + initial_offset;
-   while (frame_fill-- > 0)	/* this frame is allowed to overrun its bounds */
-      fputc('\0', fp);		/* and can do so with very low bitrate, high sample rate */
+   while (frame_fill-- > 0)     /* this frame is allowed to overrun its bounds */
+      fputc('\0', fp);          /* and can do so with very low bitrate, high sample rate */
    if (ferror(fp))
       return FAILED;
    return SUCCEEDED;
@@ -304,6 +299,18 @@ static void recorder_apply_mp3_tags(struct recorder *self)
       free(tmpname);
       return;
       }
+      
+   if (!fread(self->first_mp3_header, 4, 1, fpr))
+      {
+      fprintf(stderr, "failed to obtain the first four bytes of the recording\n");
+      fclose(fpr);
+      fclose(fpw);
+      unlink(tmpname);
+      free(tmpname);
+      return;
+      } 
+   rewind(fpr);
+      
    if (!(recorder_write_id3_tag(self, fpw) && recorder_write_vbr_tag(self, fpw)))
       {
       fprintf(stderr, "recorder_apply_mp3_tags: failed to tag the mp3 file\n");
@@ -313,7 +320,7 @@ static void recorder_apply_mp3_tags(struct recorder *self)
       free(tmpname);
       return;
       }
-   for (;;)		/* copy the mp3 file's data onto the end of the tagged file */
+   for (;;)             /* copy the mp3 file's data onto the end of the tagged file */
       {
       bytes = fread(buffer, 1, 2048, fpr);
       if (bytes == 0)
@@ -387,11 +394,6 @@ static void recorder_append_metadata2(struct recorder *self, struct encoder_op_p
          self->is_vbr = TRUE;
          fprintf(stderr, "recorder_append_metadata2: the mp3 frame length altered\n");
          }
-      else
-         {
-         if (packet->header.data_size >= 4)
-            memcpy(self->first_mp3_header, packet->data, 4);
-         }
       self->oldbitrate = packet->header.bit_rate;
       self->oldsamplerate = packet->header.sample_rate;
       }
@@ -504,6 +506,9 @@ static void *recorder_main(void *args)
    struct recorder *self = args;
    struct timespec ms10 = { 0, 10000000 };
    struct encoder_op_packet *packet;
+   char *rl, *rr, *w, *endp;
+   size_t nbytes;
+   int h, m, s;
       
    while (!self->thread_terminate_f)
       {
@@ -516,52 +521,106 @@ static void *recorder_main(void *args)
          case RM_RECORDING:
             if (!(self->watchdog_info.tick & 0x3F))
                fprintf(stderr, "recorder_main: recorder %d is recording\n", self->numeric_id);
-            if ((packet = encoder_client_get_packet(self->encoder_op)))
+               
+            if (self->initial_serial == -1)
                {
-               if (packet->header.serial >= self->initial_serial)
+               while ((nbytes = jack_ringbuffer_read(self->input_rb[1], self->right, audio_buffer_elements * sizeof (sample_t))))
                   {
-                  if ((packet->header.flags & PF_INITIAL) && self->mp3_mode)
-                     recorder_append_metadata2(self, packet);
-                  if (packet->header.flags & (PF_OGG | PF_MP3))
+                  jack_ringbuffer_read(self->input_rb[0], self->left, nbytes);
+                  rl = self->left;
+                  rr = self->right;
+                  endp = rl + nbytes;
+                  w = self->combined;
+                  while (rl != endp)
                      {
-                     if (packet->header.data_size != fwrite(packet->data, 1, packet->header.data_size, self->fp))
-                        {
-                        fprintf(stderr, "recorder_main: failed writing to file %s\n", self->pathname);
-                        self->record_mode = RM_STOPPING;
-                        }
-                     else
-                        {
-                        self->recording_length_s = (int)(self->accumulated_time + packet->header.timestamp);
-                        self->recording_length_ms = (int)((self->accumulated_time + packet->header.timestamp) * 1000.0);
-                        self->bytes_written = ftell(self->fp);
-                        }
-                     }
-                  if (packet->header.flags & PF_FINAL)
-                     {
-                     self->accumulated_time += packet->header.timestamp;
-                     if (self->pause_pending && packet->header.serial >= self->final_serial)
-                        {
-                        self->record_mode = RM_PAUSED;
-                        self->pause_pending = FALSE;
-                        fprintf(stderr, "recorder_main: entering pause mode\n");
-                        }
+                     for (int i = 0; i < sizeof (sample_t); i++)
+                        *w++ = *rl++;
+                     for (int i = 0; i < sizeof (sample_t); i++)
+                        *w++ = *rr++;
                      }
+                  sf_writef_float(self->sf, (float *)self->combined, nbytes / sizeof (sample_t));
+                  self->sf_samples += nbytes / sizeof (sample_t);
+                  if (self->stop_request || self->pause_request)
+                     break;
+                  }
+               self->recording_length_s = self->sf_samples / self->sfinfo.samplerate;
+               self->recording_length_ms = self->sf_samples * 1000 / self->sfinfo.samplerate;
+               
+               if (self->stop_request)
+                  {
+                  self->stop_request = FALSE;
+                  self->record_mode = RM_STOPPING;
+                  }
+               if (self->pause_request)
+                  {
+                  self->pause_request = FALSE;
+                  self->record_mode = RM_PAUSED;
+                  }
+                  
+               if (self->new_artist_title)
+                  {
+                  fprintf(self->fpcue, "  TRACK %02d AUDIO\r\n", ++self->artist_title_writes);
+                  
+                  pthread_mutex_lock(&self->artist_title_mutex);
+                  self->new_artist_title = FALSE;
+                  fprintf(self->fpcue, "    TITLE \"%s\"\r\n", self->title);
+                  fprintf(self->fpcue, "    PERFORMER \"%s\"\r\n", self->artist);
+                  pthread_mutex_unlock(&self->artist_title_mutex);
+
+                  s = self->recording_length_s % 60;
+                  m = self->recording_length_s / 60;
+                  fprintf(self->fpcue, "    INDEX 01 %02d:%02d:00\r\n", m, s);
                   }
-               if (packet->header.flags & PF_METADATA)
-                  recorder_append_metadata(self, packet);
-               encoder_client_free_packet(packet);
                }
-            if (self->stop_request)
+            else
                {
-               self->stop_pending = TRUE;
-               self->pause_request = TRUE;
-               self->stop_request = FALSE;
-               }
-            if (self->pause_request)
-               {
-               self->pause_pending = TRUE;
-               self->final_serial = encoder_client_set_flush(self->encoder_op);
-               self->pause_request = FALSE;
+               if ((packet = encoder_client_get_packet(self->encoder_op)))
+                  {
+                  if (packet->header.serial >= self->initial_serial)
+                     {
+                     if ((packet->header.flags & PF_INITIAL) && self->mp3_mode)
+                        recorder_append_metadata2(self, packet);
+                     if (packet->header.flags & (PF_OGG | PF_MP3))
+                        {
+                        if (packet->header.data_size != fwrite(packet->data, 1, packet->header.data_size, self->fp))
+                           {
+                           fprintf(stderr, "recorder_main: failed writing to file %s\n", self->pathname);
+                           self->record_mode = RM_STOPPING;
+                           }
+                        else
+                           {
+                           self->recording_length_s = (int)(self->accumulated_time + packet->header.timestamp);
+                           self->recording_length_ms = (int)((self->accumulated_time + packet->header.timestamp) * 1000.0);
+                           self->bytes_written = ftell(self->fp);
+                           }
+                        }
+                     if (packet->header.flags & PF_FINAL)
+                        {
+                        self->accumulated_time += packet->header.timestamp;
+                        if (self->pause_pending && packet->header.serial >= self->final_serial)
+                           {
+                           self->record_mode = RM_PAUSED;
+                           self->pause_pending = FALSE;
+                           fprintf(stderr, "recorder_main: entering pause mode\n");
+                           }
+                        }
+                     }
+                  if (packet->header.flags & PF_METADATA)
+                     recorder_append_metadata(self, packet);
+                  encoder_client_free_packet(packet);
+                  }
+               if (self->stop_request)
+                  {
+                  self->stop_pending = TRUE;
+                  self->pause_request = TRUE;
+                  self->stop_request = FALSE;
+                  }
+               if (self->pause_request)
+                  {
+                  self->pause_pending = TRUE;
+                  self->final_serial = encoder_client_set_flush(self->encoder_op);
+                  self->pause_request = FALSE;
+                  }
                }
             break;
          case RM_PAUSED:
@@ -570,27 +629,48 @@ static void *recorder_main(void *args)
             else
                if (self->unpause_request)
                   {
-                  self->initial_serial = encoder_client_set_flush(self->encoder_op) + 1;
-                  self->record_mode = RM_RECORDING;
                   self->unpause_request = FALSE;
+                  if (self->initial_serial != -1)
+                     self->initial_serial = encoder_client_set_flush(self->encoder_op) + 1;
+                  self->record_mode = RM_RECORDING;
                   }
             break;
          case RM_STOPPING:
-            fclose(self->fp);
-            if (self->mp3_mode)
+            if (self->initial_serial == -1)
                {
-               recorder_append_metadata(self, NULL);
-               recorder_append_metadata2(self, NULL);
-               recorder_display_logged_metadata(self->mi_first);
-               recorder_display_logged_metadata2(self->mi2_first);
-               recorder_apply_mp3_tags(self);
-               recorder_create_mp3_cuesheet(self);
-               recorder_free_metadata(self);
-               recorder_free_metadata2(self);
-    	       }
+               sf_close(self->sf);
+               fclose(self->fpcue);
+               self->jack_dataflow_control = JD_FLUSH;
+               while (self->jack_dataflow_control != JD_OFF)
+                  nanosleep(&ms10, NULL);
+               jack_ringbuffer_free(self->input_rb[0]);
+               jack_ringbuffer_free(self->input_rb[1]);
+               free(self->left);
+               free(self->right);
+               free(self->combined);
+               self->left = self->right = self->combined = NULL;
+               self->sf_samples = 0;
+               }
+            else
+               {
+               if (self->mp3_mode)
+                  {
+                  recorder_append_metadata(self, NULL);
+                  recorder_append_metadata2(self, NULL);
+                  recorder_display_logged_metadata(self->mi_first);
+                  recorder_display_logged_metadata2(self->mi2_first);
+                  recorder_apply_mp3_tags(self);
+                  recorder_create_mp3_cuesheet(self);
+                  recorder_free_metadata(self);
+                  recorder_free_metadata2(self);
+                  }
+               encoder_unregister_client(self->encoder_op);
+               }
+
+            fclose(self->fp);
             free(self->pathname);
-            free(self->title);
-            encoder_unregister_client(self->encoder_op);
+            free(self->cuepathname);
+            free(self->timestamp);
             memset(self->first_mp3_header, 0x00, 4);
             self->oldbitrate = 0;
             self->oldsamplerate = 0;
@@ -602,6 +682,7 @@ static void *recorder_main(void *args)
             self->bytes_written = 0;
             self->fp = NULL;
             self->pathname = NULL;
+            self->cuepathname = NULL;
             self->encoder_op = NULL;
             self->stop_request = FALSE;
             self->stop_pending = FALSE;
@@ -623,6 +704,33 @@ int recorder_make_report(struct recorder *self)
    return SUCCEEDED;
    }
 
+int recorder_new_metadata(struct recorder *self, char *artist, char *title)
+   {
+   char *new_artist, *new_title;
+   char *old_artist, *old_title;
+   
+   new_artist = strdup(artist);
+   new_title = strdup(title);
+   if (!new_artist || !new_title)
+      {
+      fprintf(stderr, "recorder_new_metadata: malloc failure\n");
+      return FAILED;
+      }
+   old_artist = self->artist;
+   old_title = self->title;
+   
+   pthread_mutex_lock(&self->artist_title_mutex);
+   self->artist = new_artist;
+   self->title = new_title;
+   self->new_artist_title = TRUE;
+   pthread_mutex_unlock(&self->artist_title_mutex);
+   
+   free(old_artist);
+   free(old_title);
+   
+   return SUCCEEDED;
+   }
+
 int recorder_start(struct threads_info *ti, struct universal_vars *uv, void *other)
    {
    struct recorder_vars *rv = other;
@@ -632,58 +740,135 @@ int recorder_start(struct threads_info *ti, struct universal_vars *uv, void *oth
    char *file_extension;
    size_t pathname_size;
    char timestamp[TIMESTAMP_SIZ];
+   size_t base;
 
-   if (!(self->encoder_op = encoder_register_client(ti, atoi(rv->record_source))))
+   if (!strcmp(rv->record_source, "-1"))
       {
-      fprintf(stderr, "recorder_start: failed to register with encoder\n");
-      return FAILED;
+      file_extension = ".flac";
+      self->encoder_op = NULL;
+      self->left = malloc(audio_buffer_elements * sizeof (sample_t));
+      self->right = malloc(audio_buffer_elements * sizeof (sample_t));
+      self->combined = malloc(audio_buffer_elements * sizeof (sample_t) * 2);
+      if (!self->left || !self->right || !self->combined)
+         {
+         fprintf(stderr, "recorder_start: malloc failure\n");
+         return FAILED;
+         }
       }
-   if (!self->encoder_op->encoder->run_request_f)
-      {
-      fprintf(stderr, "recorder_start: encoder is not running\n");
-      encoder_unregister_client(self->encoder_op);
-      return FAILED;
-      }
-   switch (self->encoder_op->encoder->data_format)
-      {
-      case DF_JACK_MP3:
-      case DF_FILE_MP3:
-         self->mp3_mode = TRUE;
-         file_extension = ".mp3";
-         break;
-      case DF_JACK_OGG:
-      case DF_FILE_OGG:
-         file_extension = ".oga";
-         break;
-      default:
-         fprintf(stderr, "recorder_start: data_format is not set to a handled value\n");
+   else
+      {      
+      if (!(self->encoder_op = encoder_register_client(ti, atoi(rv->record_source))))
+         {
+         fprintf(stderr, "recorder_start: failed to register with encoder\n");
+         return FAILED;
+         }
+      if (!self->encoder_op->encoder->run_request_f)
+         {
+         fprintf(stderr, "recorder_start: encoder is not running\n");
          encoder_unregister_client(self->encoder_op);
          return FAILED;
+         }
+      switch (self->encoder_op->encoder->data_format)
+         {
+         case DF_JACK_MP3:
+         case DF_FILE_MP3:
+            self->mp3_mode = TRUE;
+            file_extension = ".mp3";
+            break;
+         case DF_JACK_OGG:
+         case DF_FILE_OGG:
+            file_extension = ".oga";
+            break;
+         default:
+            fprintf(stderr, "recorder_start: data_format is not set to a handled value\n");
+            encoder_unregister_client(self->encoder_op);
+            return FAILED;
+         }
       }
+
    if (!(self->pathname = malloc(pathname_size = strlen(rv->record_folder) + strlen(file_extension) + TIMESTAMP_SIZ + 9)))
       {
       fprintf(stderr, "recorder_start: malloc failure\n");
-      encoder_unregister_client(self->encoder_op);
+      if (self->encoder_op)
+         encoder_unregister_client(self->encoder_op);
       return FAILED;
       }
    /* generate a timestamp filename */
    t = time(NULL);
    tm = localtime(&t);
    strftime(timestamp, TIMESTAMP_SIZ, "[%Y-%m-%d][%H:%M:%S]", tm);
-   self->title = strdup(timestamp);
+   self->timestamp = strdup(timestamp);
    snprintf(self->pathname, pathname_size, "%s/idjc.%s.%02d%s", rv->record_folder, timestamp, uv->tab+1, file_extension);
+
+   base = strlen(self->pathname) - strlen(file_extension);
+   self->cuepathname = malloc(base + 5);
+   memcpy(self->cuepathname, self->pathname, base);
+   memcpy(self->cuepathname + base, ".cue", 5);
+
    if (!(self->fp = fopen(self->pathname, "w")))
       {
       fprintf(stderr, "recorder_start: failed to open file %s\nuser should check file permissions on the particular directory\n", rv->record_folder);
       free(self->pathname);
-      free(self->title);
-      encoder_unregister_client(self->encoder_op);
+      free(self->timestamp);
+      if (self->encoder_op)
+         encoder_unregister_client(self->encoder_op);
       return FAILED;
       }
-   self->initial_serial = encoder_client_set_flush(self->encoder_op) + 1;
+   if (self->encoder_op)
+      {
+      self->initial_serial = encoder_client_set_flush(self->encoder_op) + 1;
+      fprintf(stderr, "recorder_start: awaiting serial %d to commence\n", self->initial_serial);
+      }
+   else
+      {
+      /* no encoder implies we are encoding in this module */
+      if (!(self->fpcue = fopen(self->cuepathname, "w")))
+         {
+         fprintf(stderr, "recorder_start: failed to open cue file for writing\n");
+         free(self->pathname);
+         free(self->timestamp);
+         fclose(self->fp);
+         return FAILED;
+         }
+      else
+         {
+         fprintf(self->fpcue, "TITLE \"%s\"\r\n", self->timestamp);
+         fprintf(self->fpcue, "PERFORMER \"Recorded with IDJC\"\r\n");
+         fprintf(self->fpcue, "FILE \"%s\" FLAC\r\n", strrchr(self->pathname, '/') + 1);
+         }
+      
+      self->sfinfo.samplerate = ti->audio_feed->sample_rate;
+      self->sfinfo.channels = 2;
+      self->sfinfo.format = SF_FORMAT_FLAC | SF_FORMAT_PCM_24;
+      if (!(self->sf = sf_open_fd(fileno(self->fp), SFM_WRITE, &self->sfinfo, 0)))
+         {
+         free(self->pathname);
+         free(self->timestamp);
+         fclose(self->fp);
+         fclose(self->fpcue);
+         fprintf(stderr, "recorder_start: unable to initialise FLAC encoder\n");
+         return FAILED;
+         }
+         
+      self->input_rb[0] = jack_ringbuffer_create(rb_n_samples * sizeof (sample_t));
+      self->input_rb[1] = jack_ringbuffer_create(rb_n_samples * sizeof (sample_t));
+      if (!(self->input_rb[0] && self->input_rb[1]))
+         {
+         fprintf(stderr, "encoder_start: jack ringbuffer creation failure\n");
+         free(self->pathname);
+         free(self->timestamp);
+         fclose(self->fp);
+         fclose(self->fpcue);
+         fprintf(stderr, "recorder_start: failed to create ringbuffers\n");
+         return FAILED;
+         }
+      self->jack_dataflow_control = JD_ON;  
+      self->initial_serial = -1;
+      self->new_artist_title = TRUE; /* risk inheriting old metadata rather than start with empty */
+      fprintf(stderr, "recorder_start: in FLAC mode\n");
+      }
    //if (file_extension == ".oga")
    //   recorder_write_ogg_metaheader(self);
-   fprintf(stderr, "streamer_main: connected to server - awaiting serial %d\n", self->initial_serial);
    if (self->pause_request == TRUE)
       self->record_mode = RM_PAUSED;
    else 
@@ -768,7 +953,10 @@ struct recorder *recorder_init(struct threads_info *ti, int numeric_id)
       return NULL;
       }
    self->threads_info = ti;
-   self->numeric_id = numeric_id;  
+   self->numeric_id = numeric_id;
+   self->artist = strdup("");
+   self->title = strdup("");
+   pthread_mutex_init(&self->artist_title_mutex, NULL);
    pthread_create(&self->thread_h, NULL, recorder_main, self);
    return self;
    }
@@ -777,5 +965,8 @@ void recorder_destroy(struct recorder *self)
    {
    self->thread_terminate_f = TRUE;
    pthread_join(self->thread_h, NULL);
+   pthread_mutex_destroy(&self->artist_title_mutex);
+   free(self->artist);
+   free(self->title);
    free(self);
    }
