@@ -3,7 +3,7 @@
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
+#   the Free Software Foundation, either version 2 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -37,18 +37,18 @@ class jingles:
          if existing_text != "":
             self.entry.set_text(existing_text + "," + new_text)
          else:
-            self.entry.set_text(new_text)	 
-	 
+            self.entry.set_text(new_text)        
+         
    def callback(self, widget, data):
       if data == "entrybox":
          self.play.set_active(True)
          
       if data == "Refresh":
          self.load_jingles()
-	 self.entry.set_text("")
-	 iter = self.liststore.get_iter_first()
-	 if iter != None:
-	    self.treeview.get_selection().select_iter(iter)
+         self.entry.set_text("")
+         iter = self.liststore.get_iter_first()
+         if iter != None:
+            self.treeview.get_selection().select_iter(iter)
       
       if data == "Play":
          if self.ex_is_playing and widget.get_active() == True:
@@ -81,37 +81,37 @@ class jingles:
       if data == "Stop":
          if self.play.get_active():
             self.stopping = True
-	    self.play.set_active(False)
+            self.play.set_active(False)
          if self.play_ex.get_active():
             self.stopping = True
             self.play_ex.set_active(False)
-	 self.entry.set_text("")
+         self.entry.set_text("")
 
    def get_playlist_from_entry(self):
       arglist = []
       numericlist = self.entry.get_text().split(",")
       for each in numericlist:
          if each.count("-") == 0:
-	    try:
-	       arglist.append(self.parent.idjc + "jingles/" + self.liststore[int(each)-1][1])
-	    except:
-	       pass
-	 elif each.count("-") == 1:
-	    fromto = each.split("-")
-	    try:
-	       start = int(fromto[0]) -1
-	    except:
-	       start = 0
-	    try:
-	       end = int(fromto[1]) -1
-	    except:
-	          end = 1000000
-	    while start <= end:
-	       try:
+            try:
+               arglist.append(self.parent.idjc + "jingles/" + self.liststore[int(each)-1][1])
+            except:
+               pass
+         elif each.count("-") == 1:
+            fromto = each.split("-")
+            try:
+               start = int(fromto[0]) -1
+            except:
+               start = 0
+            try:
+               end = int(fromto[1]) -1
+            except:
+                  end = 1000000
+            while start <= end:
+               try:
                   arglist.append(self.parent.idjc + "jingles/" + self.liststore[start][1])
-	       except:
-	          break;
-	       start = start + 1
+               except:
+                  break;
+               start = start + 1
       if arglist == []:
          return None
       return arglist
@@ -123,15 +123,14 @@ class jingles:
       return output 
  
    def start_player(self, mute_f):
-      self.nomute = self.parent.mic_lselect.get_active() == False and self.parent.mic_rselect.get_active() == False and self.parent.mixermode == self.parent.PRIVATE_PHONE
-      
+      self.nomute = not self.parent.mic_opener.any_mic_selected and self.parent.mixermode == self.parent.PRIVATE_PHONE
       if self.entry.get_text() == "":
          selection = self.treeview.get_selection()
-	 model, iter = selection.get_selected()
-	 if iter != None:
-	    self.entry.set_text(str(model.get_value(iter, 0)))
-	 else:
-	    self.stop.clicked()
+         model, iter = selection.get_selected()
+         if iter != None:
+            self.entry.set_text(str(model.get_value(iter, 0)))
+         else:
+            self.stop.clicked()
       playlist = self.get_playlist_from_entry()
       if playlist is not None:
          self.playing = True
@@ -139,7 +138,7 @@ class jingles:
             self.volume = self.parent.deckadj.get_value()
             if mute_f:
                self.interludevolume = self.interadj.get_value()
-	       self.interadj.set_value(100.0) 
+               self.interadj.set_value(100.0) 
                self.parent.deckadj.set_value(100.0)
             else:
                self.interludevolume = -1
@@ -177,7 +176,7 @@ class jingles:
             self.parent.mixer_write("ACTN=stopjingles\nend\n", True)
          else:
             print "stop without flush"
-            self.stop.clicked()	# this will take care of resetting the play button without triggering a flush
+            self.stop.clicked() # this will take care of resetting the play button without triggering a flush
          if self.nomute == False:
             self.parent.deckadj.set_value(self.volume)
          else:
@@ -186,7 +185,7 @@ class jingles:
             self.interadj.set_value(self.interludevolume)
          
    def delete_event(self, widget, event, data=None):
-      self.window.hide()	# We don't really destroy the window
+      self.window.hide()        # We don't really destroy the window
       return True
    
    def load_jingles(self):
@@ -195,14 +194,14 @@ class jingles:
       files = os.listdir(self.parent.idjc + "jingles")
       count = 0
       self.liststore.clear()
-      for each in files:	# files will be added with alpha numeric sorting
+      for each in files:        # files will be added with alpha numeric sorting
          if each == self.interlude_song:
             self.liststore.append([ count, each, "<b>" + rich_safe(each) + "</b>" ])
          else:
             self.liststore.append([ count, each, rich_safe(each) ])
          count = count + 1
       i = 0
-      while i < count:		# reorders the item numbers on the left column
+      while i < count:          # reorders the item numbers on the left column
          self.liststore[i][0] = i+1
          i = i + 1
       
@@ -309,7 +308,7 @@ class jingles:
       self.parent = parent
       self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
       self.parent.window_group.add_window(self.window)
-      self.window.set_title(ln.jingles_window)
+      self.window.set_title(ln.jingles_window + parent.profile_title)
       self.window.set_destroy_with_parent(True)
       self.window.set_border_width(8)
       self.window.connect("delete_event", self.delete_event)
