@@ -6,7 +6,7 @@
 #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation, either version 3 of the License, or
+#   the Free Software Foundation, either version 2 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -40,6 +40,8 @@ agc_controls = "Processed Audio Controls"
 
 agc_cutoff = "Cutoff Frequency"
 
+agc_cutoff_stages = "Stages"
+
 agc_deessbias = "Bias"
 
 agc_deesser = "De-esser"
@@ -78,7 +80,7 @@ agc_other_options = "Options"
 
 agc_phaserotator = "Phase Rotator"
 
-agc_ratio = "Ratio / Boost"
+agc_boost = "Boost/Gain (dB)"
 
 agc_right = "Right"
 
@@ -104,7 +106,9 @@ all = "All"
 
 alternate = "Alternate"
 
-announce_tip = "Enter the message you want to send here. To include the track currently playing use %s. You can also include colours using Ctrl+K (standard X-Chat/mIRC method) or from the context menu (right click)."
+alt_mic_name = "Extra open button text goes here e.g. DJ or Guest, to appear in the main window."
+
+announce_tip = "Enter the message you want to send here. To include the track currently playing use %s. You can also include colours using Ctrl+K (standard XChat/mIRC method) or from the context menu (right click)."
 
 announcement_countdown_label = "(mm:ss)   "
 
@@ -146,6 +150,10 @@ audio_meters = "Meters"
 
 auto = "Auto"
 
+autoopen = "Automatic Open"
+
+autoopen_tip = "This mic is to be opened automatically when a Player Stop or Announcement playlist control is encountered in the active player. This mic is also to be opened by the advance button."
+
 auto_start_player_tip = "Have one of the players start automatically when a radio server connection is successfully made."
 
 auto_start_recorder_tip = "Have a recorder start automatically when a radio server connection is successfully made."
@@ -168,6 +176,8 @@ basic_streamer_tip = "Run in a reduced functionality mode that lowers the burden
 
 bass_cut = "Bass cut:"
 
+basic_controls = "Basic Controls"
+
 best_quality_resample = "Highest"
 
 big_box_toggle = "Enlarge the time elapsed/remaining windows"
@@ -180,7 +190,7 @@ bitrate_tip = "The bit-rate in kilobits per second."
 
 block_size = "Block size"
 
-bonus_killer = "End tracks early: those containing excessive silence."
+bonus_killer = "End tracks early: those containing excessive silence"
 
 centre_pbspeed_tip = "This sets the playback speed back to normal."
 
@@ -226,6 +236,8 @@ conn_col_mount = "Mount point"
 
 conn_col_listeners = "Listeners"
 
+connect_disconnect_nonconfig = "Server Not Configured"
+
 connected_to_history = "connected to"
 
 connection = " Connection "
@@ -326,7 +338,7 @@ disconnection = "IDJC Disconnection"
 
 dither_tip = "This feature improves the sound quality a little when listening on a 24 bit sound card."
 
-dither_toggle = "Apply dither to MP3 and FLAC playback."
+dither_toggle = "Apply dither to MP3 and FLAC playback"
 
 dj_alarm_tip = "An alarm tone alerting the DJ that dead-air is just nine seconds away."
 
@@ -388,7 +400,7 @@ enable_tooltips = "Enable tooltips"
 
 enable_tooltips_tip = "This, what you are currently reading, is a tooltip. This feature turns them on or off."
 
-enable_track_announcer_tip = "This widget enables the track announcer which is a facility for announcing new tracks on IRC (internet relay chat) using the X-Chat IRC client. For full instructions on how to use this feature refer to the IDJC documentation in the doc folder or to the IDJC homepage."
+enable_track_announcer_tip = "This widget enables the track announcer which is a facility for announcing new tracks on IRC (internet relay chat) using the XChat IRC client. For full instructions on how to use this feature refer to the IDJC documentation in the doc folder or to the IDJC homepage."
 
 encoding = " Encoding "
 
@@ -486,7 +498,13 @@ good_quality_resample = "Good"
 
 green_phone_tip = "Mix voice over IP audio to the output stream."
 
-headroom = "Player headroom when the microphone is open (dB)"
+group = "Group"
+
+group_action = " Group Controls "
+
+group_action_tip = "Perform operations on multiple servers in unison."
+
+headroom = "Player headroom when a microphone is open (dB)"
 
 headroom_tip = "The number of dB to reduce the music players' sound level by when the microphone is switched on. A sensible setting would be 3.0 or even higher if you are not going to use ducking."
 
@@ -541,6 +559,10 @@ idjc_launch_failed = "IDJC Launch Failed"
 
 idjc_shutdown = "IDJC Shutdown"
 
+in_dj_mix = "In The DJ's Mix"
+
+in_dj_mix_tip = "Make the microphone audio audible in the DJ mix. This may not always be desirable."
+
 initial_player_settings = "Player Settings At Startup"
 
 interval = "Interval:"
@@ -553,6 +575,10 @@ invert_right = "Invert right mic audio"
 
 invert_right_tip = "Performs phase inversion on the right microphone signal. Use this to make both microphones be in phase with one another and to affect phase in relation to your voice with respect to the headphones."
 
+invert_mic = "Invert Signal"
+
+invert_mic_tip = "Useful for when microphones are cancelling one another out, producing a hollow sound."
+
 irc_channels_tip = "A comma separated list of IRC channels. Some IRC servers require that you also be logged into the channel before you can announce there."
 
 irc_message_timer = "IRC Message Timer"
@@ -566,11 +592,11 @@ item_menu = "Item"
 jack_connection_failed = """The JACK sound server needs to be running in order to run IDJC.
 In order to manually start it try something like:
 
-	$ jackd -d alsa -r 44100 -p 2048
+        $ jackd -d alsa -r 44100 -p 2048
 
 If you would like JACK to start automatically with your user specified parameters try something like this, which will create a file called .jackdrc in your home directory:
 
-	$ echo "/usr/bin/jackd -d alsa -r 44100" > ~/.jackdrc
+        $ echo "/usr/bin/jackd -d alsa -r 44100" > ~/.jackdrc
 
 If you have already done this it is possible another application or non-JACK sound server is using the sound card.
 
@@ -578,13 +604,13 @@ Possible remedies would be to close the other audio app or configure the sound s
 
 If you are trying to connect to a named jack server, either set the environment variable JACK_DEFAULT_SERVER to that name or launch IDJC with the -j jackservername option. For example:
 
-	 $ jackd -n xyzzy -d alsa -r 44100 -p 2048 &
-	 $ idjc -p profilename -j xyzzy"""
+         $ jackd -n xyzzy -d alsa -r 44100 -p 2048 &
+         $ idjc -p profilename -j xyzzy"""
 
 jack_entry = """Enter the name of the JACK audio port with which to bind and then click the set button to the right.
 Typing 'jack_lsp -p' in a console will give you a list of valid JACK audio ports. Note that inputs will only bind to output ports and outputs will only bind to input ports."""
 
-jack_ports_tab = "Jack Ports"
+jack_ports_tab = "JACK Ports"
 
 jingles_button = "Jingles"
 
@@ -598,6 +624,14 @@ jingles_window = "IDJC Jingles"
 
 jingles_window_open_tip = "Open the jingles player window."
 
+kick_before_start = "Kick Before Start"
+
+kick_before_start_tip = "Disconnect whoever is using the server just before start time."
+
+kick_incumbent = "Kick Incumbent"
+
+kick_incumbent_tip = "This will disconnect whoever is currently using the server, freeing it up for personal use."
+
 l = "L"
 
 label_icecast_master = "Icecast 2 Master"
@@ -620,7 +654,7 @@ left_playlist_save = "Save left playlist"
 
 level = "Level"
 
-licence = "Released under the GNU General Public License V3.0"
+licence = "Released under the GNU General Public License V2.0"
 
 licence_tab = "Licence"
 
@@ -684,11 +718,11 @@ metadata_source_label = "Metadata Source"
 
 metadata_source_last_played = "Last Played"
 
-metadata_source_left_deck = "Left Deck"
+metadata_source_left_deck = "Left Player"
 
 metadata_source_none = "None"
 
-metadata_source_right_deck = "Right Deck"
+metadata_source_right_deck = "Right Player"
 
 metadata_source_tip = "Select which Deck is responsible for the metadata on the stream."
 
@@ -704,27 +738,31 @@ mic_compression_level_tip = "Controls whether to display a meter indicating the
 
 mic_in_phones = "Hearing your voice in your headphones (somewhat delayed) can be distracting which is why some users might want to turn this feature off."
 
+mic_simple = "Simple (low CPU drain)"
+
+mic_processed = "Full Signal Processing"
+
+mic_complexity_tip = "Use this to turn on microphone signal processing which may be all you need to make a cheap mic sound like a more expensive one or achieve a studio sound. The simple options on the other hand place less demand on the CPU and may be all you require."
+
 mic_off_tip = "Each time the microphone is turned off run the commands to the right."
 
 mic_on_tip = "Each time the microphone is turned on run the commands to the right."
 
 mic_peak = "Mic Peak"
 
-mic_peak_meter_tip = "A peak hold meter indicating the strength of the audio from each individual microphone."
+mic_meter_tip = "A peak hold meter indicating the microphone signal strength and a meter indicating attenuation levels in the microphone signal processing system. Green indicates attenuation from the noise gate, yellow from the de-esser, red from the limiter."
 
 mic_peak_toggle = "Mic Peak"
 
 mic_peak_toggle_tip = "Controls whether to display a peak-hold signal level meter in the main application window indicating the signal strength of the individual microphone audio levels."
 
-mic_to_dj = "Send microphone audio (mono) to the DJ's headphones"
-
 mic_toggle_tip = "This button toggles the microphone input for both the left and the right microphones. To select microphones individually, right click on this button."
 
 mic_vu = "Mic VU"
 
 mic_vu_meter_tip = "A VU meter for the microphone audio."
 
-microphone_tab = "Microphone"
+microphone_tab = "Microphones"
 
 middle = "Middle"
 
@@ -800,6 +838,8 @@ nick = "Nick:"
 
 nick_entry_tip = "The nick specified here must match at least one of the nicks you are logged into IRC as"
 
+no_microphones = "No Microphones"
+
 no_more_ask = "Don't ask again"
 
 no_mp3_stream_available = ('To enable MP3 streaming', 'install the package named', "'libmp3lame'", 'and restart IDJC.')
@@ -836,13 +876,21 @@ ogg_streamtab_tip = "Clicking this tab selects the Ogg family of file formats."
 
 open_aux_element = "Switch to Aux input"
 
-other_mic_options = "Other Options"
+open_mic = "Open/Unmute"
 
-panning = "Stereo Panning"
+open_unmute_tip = "This controls the allocation of front panel open/unmute buttons. Having one button control multiple microphones can save time." 
 
-panning_mono = "Mono"
+open_mic_tip = "Allow microphone audio into the mix."
 
-panning_no_audio = "No Audio Source Selected"
+other_mic_options = "General Mic Options"
+
+pan = "Stereo Panning"
+
+pan_tip = """Stereo panning is the selection of where an audio source sits from left to right within the stereo mix.
+
+This control maintains constant audio power throughout its range of travel, giving -3dB attenuation in both audio channels at the half way point.
+
+If you require 0dB straight down the middle then this feature should be turned off."""
 
 pass_button_tip = "This button causes the crossfader to move to the opposite side at a speed determined by the speed selector to the left."
 
@@ -872,7 +920,7 @@ player_1 = "Player 1"
 
 player_2 = "Player 2"
 
-player_resample_mode = "Player resample quality"
+player_resample_mode = "Player Resample Quality"
 
 player_resample_quality = "This adjusts the quality of the audio resampling method used whenever the sample rate of the music file currently playing does not match the sample rate of the JACK sound server. Highest mode offers the best sound quality but also uses the most CPU (not recommended for systems built before 2006). Fastest mode while it uses by far the least amount of CPU should be avoided if at all possible."
 
@@ -988,9 +1036,9 @@ rdc_discard_data = "Discard data"
 
 rdc_attempt_reconnection = "Attempt reconnection"
 
-rec_directory_tip = "Choose which directory you want to save to. All file names will be in a timestamp format and have either an ogg or mp3 file extension. Important: you need to select a directory to which you have adequate write permission."
+rec_directory_tip = "Choose which directory you want to save to. All file names will be in a timestamp format and have either an oga, mp3, or flac file extension. Important: you need to select a directory to which you have adequate write permission."
 
-rec_source_tip = "Chooses which stream to record. If the stream isn't running the encoder will be started for you. Remember to make sure the encoder settings are to your liking before you start recording."
+rec_source_tip = "Choose which stream to record or the 24 bit FLAC option. If the stream isn't already running the encoder will be started automatically using whatever settings are currently configured."
 
 recon_tip = """A set of controls for managing what happens when the server connection either breaks or suffers prolonged congestion.
  
@@ -1048,9 +1096,9 @@ restore_session = "Restore previous session"
 
 restore_session_tip = "When starting IDJC most of the main window settings will be as they were left. As an alternative you may specify below how you want the various settings to be when IDJC starts."
 
-rg_indicate = "Indicate which tracks have Replay Gain values."
+rg_indicate = "Indicate which tracks have Replay Gain values"
 
-rg_adjust = "Adjust playback volume."
+rg_adjust = "Adjust playback volume"
 
 rg_defaultgain = "Gain value for unmarked tracks:"
 
@@ -1096,13 +1144,13 @@ send_metadata = "Send Metadata"
 
 sequence = "Sequence:"
 
-server_button = "Server"
+output_button = "Output"
 
 server_connect = "Server Connect"
 
 server_connect_tip = """Connect to or disconnect from the radio server. If the button does not stay in, the connection failed for some reason.
  
-If the button is greyed out it means you are using unsupported settings. Shoutcast only supports mp3 and mp3 requires that you use one of the sample rates in the drop down box. Ogg only supports certain sample rate, bit rate, and stereo combinations."""
+If the button is greyed out it means you are using unsupported settings. Shoutcast only supports mp3 and mp3 requires that you use one of the sample rates in the drop down box. Ogg only supports certain sample rate, bit rate, and stereo combinations. Also, the connection list must contain details for a master server."""
 
 server_host = "Host:"
 
@@ -1120,16 +1168,20 @@ server_type_icecast2 = "Icecast 2"
 
 server_type_shoutcast = "Shoutcast"
 
-server_type_tip = "IDJC can connect to both Icecast and Shoutcast servers. For connection to be successful you need to specify the type of server that you wish to connect to. Also note, you can specify a relay here for the purpose of stats collection. If a master has already been added to the list above you can't add another one - to stream to more than one server use a different server tab instead."
+server_type_tip = "IDJC can connect to both Icecast and Shoutcast servers. For connection to be successful you need to specify the type of server that you wish to connect to. Also note, you can specify a relay here for the purpose of stats collection. If a master has already been added to the list above you can't add another one - to stream to more than one server use a different stream tab instead."
 
 server_type_codes = ("I2M", "SM", "I2R", "SR")
 
 server_type_labels = ("Icecast 2 Master", "Shoutcast Master",
                       "Icecast 2 Stats/Relay", "Shoutcast Stats/Relay")
 
-server_window = "Radio Server"
+stream_details = "Server Details & Stream Format"
 
-server_window_open_tip = "Open the radio server connection window."
+stream_details_tip = "The user interface for changing server connection details and the stream format, e.g. mp3 or vorbis, is contained within. Be sure to scroll down and enter as much information as is necessary."
+
+output_window_title = "IDJC Output"
+
+output_window_open_tip = "Open the output window."
 
 set = "Set"
 
@@ -1137,12 +1189,18 @@ set_tip = "Reroute the audio to/from the specified port"
 
 settings_warning_tip = "Adjust these settings carefully since they can have subtle but undesireable effects on the sound quality."
 
-silence_killer = "End tracks early: those that have quiet endings."
+sideline = "Sideline"
+
+sideline_tip = "A user interface clutter removal feature for unused or problematic streams."
+
+silence_killer = "End tracks early: those that have quiet endings"
 
 sharp = "Sharp"
 
 shell_commands_tip = "Enter bash shell commands to run, separated by a semicolon for this particular event."
 
+show_microphone_meters = "Microphone Meters"
+
 song_placemarker = "Song name place marker = %s"
 
 speed_variance = "Enable the main-player speed/pitch controls"
@@ -1191,6 +1249,8 @@ statusbar_tip = """'Block size' indicates the amount of time that it will take t
 
 std_mp3_rate_tip = "Use one of the standard mp3 bit rates."
 
+show_stream_meters = "Stream Audio Levels And Connections"
+
 stereo = "Stereo"
 
 stop_control_element = "Player stop"
@@ -1283,10 +1343,14 @@ test_monitor = " Test / Monitor "
 
 this = "This"
 
+those_active = "Only Those Active"
+
 threshold = "Thresh."
 
 time = "Time"
 
+timer = "Timer:"
+
 timed_out = ('Automatically disconnected from the server,', 'after the connection timed out.')
 
 to_here = "To Here"
@@ -1373,3 +1437,11 @@ wet_voice_volume_tip = "This adjusts the volume level of the music that plays wh
 
 window_close = "Close"
 
+xchat_install_tip = "Having problems? Launch XChat, close XChat, press this button, launch XChat again."
+
+xchat_install = "Install The XChat Plugin"
+
+xchat_install_done = "The XChat Plugin Is Already Installed"
+
+xchat_install_failed = "The Plugin Would Not Install -- Try Again?"
+
